<!-- KDG System Configuration Utility v0.9 (beta) (15072007) --> 


<!-- ----------------------------------------------------------------------------------------------------------------------

API Documentation

About System Configuration Utility
==================================
SCU lets you load up the settings file for a website or web system
and changes which are saved back into the original include file.

Using SCU
=========
SCU is very particular about the sort of file it expects. The include
file you want to edit must be formatted correctly or the system wont
work.

Example of a Well Formatted Settings File
=========================================

<-%
const WEBSITE = "ECE v2 Sandbox"

const FONT_CHANGING_ENABLED = false
const FONT_SIZE_CHANGING_ENABLED = false
const COLOUR_PICKER_ENABLED = false

const PHOTO_GALLERY_ACCESS_ENABLED = false
const REMEMBER_PASSWORD_CHECKBOX_ENABLED = true
const HTML_TABLES_ENABLED = false

const BULLET_LISTS_ENABLED = false
%->

Note that the normal ASP processor tags are shown as <-% and %-> here.

The Rules
=========
* the settings file must only contant constants.
* the very first line in the file must be the opening ASP processor tag.
* the very last line in the file must be the closing ASP processor tag.
* the first constant should state the website or system name (eg. const WEBSITE = "The Lounge Room")
* whenever you use the SCU with a website or system, you must set 'INC_FILE_LOCATION' and 'INC_FILE_NAME' in the SCU file.
* be aware that the SCU will save exactly what's been typed into a textbox for a particular constant.
* for string constants, you do need to put in quote marks (eg. "Last Update: 20/11/2004" <- this is correct).
* don't be surprised if the SCU strips your *.inc file of all its CRLF's.
* you have to put in the change auth code before the *.inc file can be re-written.

---------------------------------------------------------------------------------------------------------------------- -->

<% 
'------------------------------------------------------------------------------------------------------------------------
'*** CONSTANTS & VARIABLES ***

const INC_FILE_NAME = "global_constants.inc"

const LOCAL_FILE_PATH = "include\"
const LIVE_FILE_PATH = "..\..\..\public\bugnet\"

const LOGIN_USERNAME = "bugnet"
const LOGIN_PASSWORD = "b2007"
const AUTHORISATION_CODE = "3149"
const SITE_CONSTANTS_TIMESTAMP = "v1.1 (051107)"

Dim g_strASPOpenPreProcessor
Dim g_strASPClosePreProcessor
Dim g_strSettingFilePathAndName

Dim g_strArrProcessedSettings
Dim g_strArrRawSettings

Dim g_strLowerColour
Dim g_strUpperColour
Dim g_bSaveJustOccurred

Dim g_strFilePath

'------------------------------------------------------------------------------------------------------------------------
'*** FUNCTION CALLS***

StartupSCU()

PerformSecurityCheck()

GetSettingsFileContent()

SaveSettings()

DrawAppropriateSCU_Page()

'------------------------------------------------------------------------------------------------------------------------
'*** FUNCTIONS ***

Function StartupSCU()

	g_strASPOpenPreProcessor = Chr(60) & Chr(37)
	g_strASPClosePreProcessor = Chr(37) & Chr(62)
	
	g_strFilePath = GetFilePath()

	g_strSettingFilePathAndName = GetCurrentFileLocation() & g_strFilePath & INC_FILE_NAME
	
	g_strUpperColour = "#CCCCCC"
	g_strLowerColour = "#F2F2F2"

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetFilePath()

	Dim strRtnValue

	'check if its an internal network ip address, that will be taken as a development environment
	if (InStr(Request.ServerVariables("SERVER_NAME"), "192.") = 0) then
		strRtnValue = LIVE_FILE_PATH
	else
		strRtnValue = LOCAL_FILE_PATH
	end if
	
	GetFilePath = strRtnValue
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function DrawAppropriateSCU_Page()

	if (g_bSaveJustOccurred = true) then
		Dim strSaveMessage
		
		strSaveMessage = "Settings saved (<a href=""" & _
								  	 GetPageName() & "?u=" & LOGIN_USERNAME & "&p=" & LOGIN_PASSWORD & """>return</a>)."
			
		Call DrawSCU_MessageHTML(strSaveMessage, "#D6E0D9", "#003300")
	else
		DrawSCUPageHTML()
	end if

End Function
'------------------------------------------------------------------------------------------------------------------------
Function SaveSettings()

	'see if a save operation is to be performed
	if (Request.QueryString("save_settings") = "1") then
	
		Dim strSubmittedAuthCode
		
		strSubmittedAuthCode = Request.Form("txt_authorisation_code")
	
		'check that the change authorisation code is correct
		if (IsAuthCodeValid(strSubmittedAuthCode) = true) then
			WriteSettingFile()
			g_bSaveJustOccurred = true
		else
			Call DrawSCU_MessageHTML("Authorisation code is invalid.", "#FFCC99", "#800000")
			Response.End
		end if
	
	else
		g_bSaveJustOccurred = false
	end if

End Function
'------------------------------------------------------------------------------------------------------------------------
Function WriteSettingFile()
	
	Dim iCounter
	Dim strArrNewSettings
	Dim strUpdatedSettings

	'reconstruct the constants and their associated values. this will get saved back into the original settings file.
	strArrNewSettings = FilterForBlanks( Split(PrepareStringForSplit(g_strArrRawSettings), vbCrLf) )
	
	're-construst the settings content with the new form values.
	For iCounter = 0 To UBound(strArrNewSettings)
		strUpdatedSettings = strUpdatedSettings & UpdateConstValue( strArrNewSettings(iCounter), Request.Form(iCounter + 1) )
	Next

	'tack on the ASP processor tags
	strUpdatedSettings = g_strASPOpenPreProcessor & vbCrLf & strUpdatedSettings & g_strASPClosePreProcessor
	
	Call CreatePhysicalFile(g_strSettingFilePathAndName, strUpdatedSettings)
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function UpdateConstValue(strInputOriginalConstLine, strInputNewConstValue)

	Dim strRtnValue
	Dim strLeftSide
	Dim strRightSide
	Dim strArrConstAndValue
	
	strArrConstAndValue = Split(strInputOriginalConstLine, "=")
	
	strLeftSide = Trim(strArrConstAndValue(0))
	strRightSide = strNewConstValue
	
	strRtnValue = "const " & strLeftSide & " = " & strInputNewConstValue & vbCrLf
	
	UpdateConstValue = strRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function CreatePhysicalFile(strInputFilePathAndName, strInputFileContents)

	const OVERWRITE_FILE = true
	const DONT_OVERWRITE_FILE = false

	Dim objFSO
	Dim objTextStream
	
	Set objFSO = Server.CreateObject("Scripting.FileSystemObject")
	
	'create a file
	Set objTextStream = objFSO.CreateTextFile(strInputFilePathAndName, OVERWRITE_FILE)
	
	'write text to the file
	objTextStream.WriteLine strInputFileContents
	
	'close the file and clean up
	objTextStream.Close
	Set objTextStream = Nothing
	Set objFSO = Nothing

End Function
'------------------------------------------------------------------------------------------------------------------------
Function IsAuthCodeValid(strInputAuthCode)

	Dim bRtnValue

	if (strInputAuthCode = AUTHORISATION_CODE) then
		bRtnValue = true
	else
		bRtnValue = false
	end if
	
	IsAuthCodeValid = bRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function PerformSecurityCheck()
	
	Dim strLoginUsername
	Dim strLoginPassword
	Dim bLoginWasSuccessful
	
	'check if the user is already logged in
	if (Request.Form("user_is_verified") = "1") then
		Exit Function		
	end if
	
	strLoginUsername = Request.QueryString("u")
	strLoginPassword = Request.QueryString("p")
	bLoginWasSuccessful = false
	
	if ((strLoginUsername = LOGIN_USERNAME) AND strLoginPassword = LOGIN_PASSWORD) then
		bLoginWasSuccessful = true
	end if

	if (bLoginWasSuccessful = false) then
		Call DrawSCU_MessageHTML("Login attempt unsuccessful.", "#FFFFEC", "#800000")
		Response.End
	end if
		
End Function
'------------------------------------------------------------------------------------------------------------------------
Function DrawSCU_MessageHTML(strInputMessage, strInputBackgroundColour, strInputTextColour)

	%>
	<table border="0" cellpadding="0" style="border-collapse: collapse" width="100%" height="100%">
	<tr>
		<td align="center">
		
	<table border="1" bordercolor="#808080" cellpadding="5" bordercolorlight="#808080" bordercolordark="#808080" cellspacing="0" style="border-collapse: collapse">
	<tr>
		<td bgcolor="<%= strInputBackgroundColour %>"><font face="Verdana" size="2" color="<%= strInputTextColour %>"><%= strInputMessage %></font></td>
	</tr>
	</table>
	
		</td>
	</tr>
	</table>
	<%
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetSettingValueByPosition(iInputArrayElement)

	Dim strRtnValue
	
	strRtnValue = Split(g_strArrProcessedSettings(iInputArrayElement), "=")(1)
	
	strRtnValue = Replace(strRtnValue, Chr(34), "&quot;")
	
	GetSettingValueByPosition = Trim(strRtnValue)

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetConstantName(iInputArrayElement)

	Dim strRtnValue
	
	strRtnValue = Split(g_strArrProcessedSettings(iInputArrayElement), "=")(0)

	
	GetConstantName = Trim(strRtnValue)

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetSettingsFileContent()
	
	Dim strRawSettingsFileContent
	Dim strProcessedSettingsFileContent
	
	g_strArrRawSettings = GetRawSettingsFileContent(g_strSettingFilePathAndName)

	g_strArrRawSettings = StripAspPreProcessorTags(g_strArrRawSettings)
	
	g_strArrProcessedSettings = ProcessSettingsFileContent(g_strArrRawSettings)
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function PrepareStringForSplit(strInputSettingsStringToPrepare)

	Dim strRtnValue
	
	strRtnValue = strInputSettingsStringToPrepare
	
	'clean up the file for later use
	strRtnValue = Replace(strRtnValue, "const", "")
	strRtnValue = Replace(strRtnValue, "Const", "")
	strRtnValue = Replace(strRtnValue, "CONST", "")
	strRtnValue = Replace(strRtnValue, " = ", "=")
	strRtnValue = Replace(strRtnValue, "= ", "=")
	strRtnValue = Replace(strRtnValue, " =", "=")
	
	PrepareStringForSplit = strRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function ProcessSettingsFileContent(strInputRawSettingsFileContent)

	Dim strRtnValue
	Dim strArrSettings
	Dim strArrFilteredSettings

	strRtnValue = PrepareStringForSplit(strInputRawSettingsFileContent)
	
	strArrSettings = Split(strRtnValue, vbCrLf)
	
	strArrFilteredSettings = FilterForBlanks(strArrSettings)
	
	ProcessSettingsFileContent = strArrFilteredSettings

End Function
'------------------------------------------------------------------------------------------------------------------------
Function FilterForBlanks(strArrInputArrayToFilter)

	Dim strArrRtnValue
	Dim iCounter
	Dim strFilteredString
	
	For iCounter = 0 To UBound(strArrInputArrayToFilter)

		if (Not Trim(strArrInputArrayToFilter(iCounter)) = "") then
			strFilteredString = strFilteredString & Trim(strArrInputArrayToFilter(iCounter)) & "###"
		end if
		
	Next
	
	'remove the delimiter on the end of the string
	strFilteredString = Left(strFilteredString, Len(strFilteredString) - 3)
	
	strArrRtnValue = Split(strFilteredString, "###")
	
	FilterForBlanks = strArrRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function StripAspPreProcessorTags(strInputFileContents)

	Dim strRtnValue
	
	strRtnValue = Replace(strInputFileContents, g_strASPOpenPreProcessor, "") 'take off the CRLF after the processor tag too.
	strRtnValue = Replace(strRtnValue, g_strASPClosePreProcessor, "")
	
	StripAspPreProcessorTags = strRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetCurrentFileLocation()

	Dim strRtnValue
	
	strRtnValue = Replace(Request.ServerVariables("PATH_TRANSLATED"), GetPageName(), "")
	
	GetCurrentFileLocation = strRtnValue

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetPageName()

	'get the name of the current page
	Dim strTempPageName

	strTempPageName = Split(Request.ServerVariables("SCRIPT_NAME"),"/")
	
	GetPageName = strTempPageName(UBound(strTempPageName))

End Function
'------------------------------------------------------------------------------------------------------------------------
Function GetRawSettingsFileContent(strInputSettingFilePathAndName)

	Dim strRtnValue
	
	strRtnValue = ReadFile(strInputSettingFilePathAndName)
	
	GetRawSettingsFileContent = strRtnValue
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function ReadFile(strInputFileToRead)

	'note: file input name must include a full directory path.

	const FSO_FOR_APPEND = 8
	const FSO_FOR_WRITING = 2 
	const FSO_FOR_READING = 1
	
	Dim objFSO
	Dim objTextStream
	Dim strRtnValue
	
	Set objFSO = Server.CreateObject("Scripting.FileSystemObject")
	
	If objFSO.FileExists(strInputFileToRead) then
		
		'The file exists, so open it and output its contents
		Set objTextStream = objFSO.OpenTextFile(strInputFileToRead, FSO_FOR_READING)
		
		strRtnValue = objTextStream.ReadAll
		
		objTextStream.Close
		Set objTextStream = Nothing
		
	else

		'The file could not be found
		Response.Write "An error has occurred. The file: '" & strInputFileToRead & "' could not be found.<br>"
		
	end if
	
	'release resources
	Set objFSO = Nothing

	ReadFile = strRtnValue
	
End function
'------------------------------------------------------------------------------------------------------------------------
Function ConvertToTitleCase(strInput)

	Dim iStringLength, strArrString, iCounter, strTitleCaseString

	iStringLength = Len(strInput)
	ReDim strArrString(iStringLength)
	
	For iCounter = 0 to iStringLength
	
		if iCounter = 0 then
			'convert the first letter for the string to uppercase
			strArrString(iCounter) = UCase(Mid(strInput, iCounter + 1, 1))
		elseif strArrString(iCounter - 1) = " " then
			'convert the letter to uppercase if it comes after a space
			strArrString(iCounter) = UCase(Mid(strInput, iCounter + 1, 1))
		else
			'leave the letter in lowercase
			strArrString(iCounter) = Mid(strInput, iCounter + 1, 1)
		end if

	Next

	'move the array of characters to a proper string
	For iCounter = 0 to iStringLength
		strTitleCaseString = strTitleCaseString & strArrString(iCounter)
	Next
	
	ConvertToTitleCase = strTitleCaseString

End Function
'------------------------------------------------------------------------------------------------------------------------
Function DrawSettingPairsHTML()

	const USE_SMALL_TEXTBOX = 16
	const USE_MEDIUM_TEXTBOX = 64
	const USE_LARGE_TEXTBOX = 100

	Dim iCounter
	Dim iConstantValueLength
	Dim strSettingLabel
	Dim strSettingValue

	For iCounter = 0 To UBound(g_strArrProcessedSettings)
		
		strSettingLabel = GetConstantName(iCounter)
		strSettingValue = GetSettingValueByPosition(iCounter)
		iConstantValueLength = Len(strSettingValue) 
		%>
		<tr>
			<td valign="top" class="constant_label" align="right"><%= ConvertToTitleCase(strSettingLabel) %>:</td>
	  	<td>&nbsp;</td>
			<td class="constant_setting">
			<% 
			'set the control type based on length of constant value
			if (iConstantValueLength < USE_SMALL_TEXTBOX) then
				%><input type="text" value="<%= strSettingValue %>" class="form_control_textbox_small" name="txt_<%= LCase(strSettingLabel) %>" size="40" maxlength="512"><%
			elseif (iConstantValueLength > USE_SMALL_TEXTBOX AND iConstantValueLength < USE_MEDIUM_TEXTBOX) then
				%><input type="text" value="<%= strSettingValue %>" class="form_control_textbox_medium" name="txt_<%= LCase(strSettingLabel) %>" size="40" maxlength="512"><%
			elseif (iConstantValueLength > USE_MEDIUM_TEXTBOX AND iConstantValueLength < USE_LARGE_TEXTBOX) then
				%><input type="text" value="<%= strSettingValue %>" class="form_control_textbox_large" name="txt_<%= LCase(strSettingLabel) %>" size="40" maxlength="512"><%
			else
				%><textarea class="form_control_textbox_large" rows="3" name="txt_<%= LCase(strSettingLabel) %>" cols="20"><%= strSettingValue %></textarea><%
			end if
			%>
			 </td>
		</tr>
		<% 
	Next
	
End Function
'------------------------------------------------------------------------------------------------------------------------
Function ConvertToTitleCase(strInput)

	Dim iStringLength
	Dim strArrString
	Dim iCounter
	Dim strTitleCaseString

	strInput = LCase(Replace(strInput, "_", " "))
	
	iStringLength = Len(strInput)
	ReDim strArrString(iStringLength)
	
	For iCounter = 0 to iStringLength
	
		if iCounter = 0 then
			'convert the first letter for the string to uppercase
			strArrString(iCounter) = UCase(Mid(strInput, iCounter + 1, 1))
		elseif strArrString(iCounter - 1) = " " then
			'convert the letter to uppercase if it comes after a space
			strArrString(iCounter) = UCase(Mid(strInput, iCounter + 1, 1))
		else
			'leave the letter in lowercase
			strArrString(iCounter) = Mid(strInput, iCounter + 1, 1)
		end if

	Next

	'move the array of characters to a proper string
	For iCounter = 0 to iStringLength
		strTitleCaseString = strTitleCaseString & strArrString(iCounter)
	Next
	
	ConvertToTitleCase = strTitleCaseString

End Function
'------------------------------------------------------------------------------------------------------------------------
Function DrawSCUPageHTML()

%>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<html>
<head>
	<title>Site Constants</title>
		
	<style type="text/css">
	body
	{
	  font-family: Verdana;
	  font-size: 11px;
		color: #333333;
	}
	
	td
	{
	  font-family: Verdana;
	  font-size: 11px;
		color: #333333;
	}
	
	.heading
	{
		font-family: Verdana;
	  font-weight: bold;
		font-size: 15px;
		color: #333333;
	}
	
	.form_control_button
	{
	  font-family: Verdana;
	  font-size: 10px;
		width: 55px;
		height: 22px;
		padding-bottom: 3px !ie;
		padding-bottom: 1px;
	}
	
	.form_control_textbox
	{
	  font-family: Verdana;
	  font-size: 10px;
		width: 500px;
	}
	
	.form_control_textbox_small
	{
	  font-family: Verdana;
	  font-size: 11px;
		width: 50px;
	}
	
	.form_control_textbox_medium
	{
	  font-family: Verdana;
	  font-size: 11px;
		width: 450px;
	}
	
	.form_control_textbox_large
	{
	  font-family: Verdana;
	  font-size: 11px;
		width: 450px;
	}
	
	.footer_time_stamp
	{
	  font-family: Verdana;
	  font-size: 7.5pt;
		color: #E0E0E0;
		color: #808080;
	}
	
	.small_text
	{
	  font-family: Verdana;
	  font-size: 8pt;
		color: #666666;
	}
	
	.constant_setting
	{
	 	padding-right: 10px;
		padding-top: 2px;	
	}
	
	.constant_label
	{	
	 	padding-left: 10px;
		padding-top: 4px;		
	}
	
	</style>
	
</head>

<body>

<table border="0" cellpadding="0" style="border-collapse: collapse" width="100%" height="100%">
<tr>
	<td align="center">
	
<table border="1" cellpadding="4" style="border-collapse: collapse" bordercolor="#000000" cellspacing="0">
<tr>
	<td bgcolor="<%= g_strUpperColour %>" align="center">
		<SPAN class="heading">Site Constants</SPAN>
		<br>
    <SPAN class="small_text">Website: <%= Replace(GetSettingValueByPosition(0), "&quot;", "") %></SPAN>
	</td>
</tr>
<tr>
	<td bgcolor="<%= g_strLowerColour %>">

<table border="0" cellpadding="0" style="border-collapse: collapse" width="100%">
<tr>
	<td><b>Settings</b></td>
</tr>
<tr>
	<td height="5"></td>
</tr>
</table>

<table border="0" cellpadding="0" style="border-collapse: collapse" width="100%">
	<form name="frm_web_section_to_edit" action="<%= GetPageName() %>?save_settings=1" method="post">
	<% DrawSettingPairsHTML() %>
<tr>
	<td colspan="3" height="12"></td>
</tr>		
<tr>
	<td align="right">Auth. Code:</td>
 	<td>&nbsp;</td>
	<td><input  type="text" value="" class="form_control_textbox_small" name="txt_authorisation_code" size="12" maxlength="32"></td>
</tr>	
</table>

<br>
<table border="0" cellpadding="0" style="border-collapse: collapse" width="100%">

<tr>
	<td valign="bottom"><SPAN class="footer_time_stamp"><%= SITE_CONSTANTS_TIMESTAMP %></SPAN></td>
	<td align="right">
	<% 
	Dim strReturn
	strReturn = Replace("http://" & Request.ServerVariables("SERVER_NAME") & Request.ServerVariables("SCRIPT_NAME"), "/" & GetPageName(),"")
	%>
	<input class="form_control_button" type="submit" value="Save" name="btnSave">
	<input class="form_control_button" type="reset" value="Reset" name="btnReset">
	<input class="form_control_button" type="button" OnClick="javascript: window.location.href='settings.asp';" value="Return" name="btnReturnToCMS">
	<input type="hidden" name="user_is_verified" value="1">

	</td>
</tr>
</form>
</table>

	</td>
</tr>
</table>
	
	</td>
</tr>
</table>

</body>
</html>
<%

End Function
'------------------------------------------------------------------------------------------------------------------------
%>